dofile ("./Config/Export/weaponsTypeIndicator.lua")
-- Globals
gLastGunStatus = "SAFE"
gLastWeaponType = 0



-- Support functions to parse and generate suitable commands to the SIOC server.
-- Process simple On/Off indicators
function ProcessIndicators(pIndicatorTables)
    local lIndicatorTable, lDevice_Arg ,lSIOC_Var, lArgumentValue, lPanel, lPanelId
    local lSIOC_SendString = ""
    
    for i , lIndicatorTable in pairs(pIndicatorTables) 
    do     
        for lSIOC_Var ,lDevice_Arg in pairs(lIndicatorTable) 
        do 
            -- Check if the panelID changes between indicators 
            if lPanelId ~= lDevice_Arg[1] then 
                lPanelId = lDevice_Arg[1]
                -- Get the device
                lPanel = GetDevice(lDevice_Arg[1])
                --Check to see that the device is valid otherwise we return an emty string
                if type(lPanel) ~= "table" then
                    return ""
                end
                -- Update the panel
                lPanel:update_arguments()
            end
             
            lArgumentValue = lPanel:get_argument_value(lDevice_Arg[2])
            -- For some reason the get_argument_value function call above returns 0.1000001256, 0.20000012313 
            -- or similar so we need round this value to 0.1, 0.2 etc
            lArgumentValue = round(lArgumentValue, 1)
    
            -- 0 or 0.2 means that the indicator should be off => the SIOC param should be 0
            -- For any other value the indicator should be on => the SIOC param should be 1
            if ((lArgumentValue == 0) or (lArgumentValue == 0.2)) then
                lSIOC_SendString = lSIOC_SendString..lSIOC_Var.."=0:"
            else
                lSIOC_SendString = lSIOC_SendString..lSIOC_Var.."=1:"
            end            
        end
    end
    return lSIOC_SendString
end


-- Calculate and generate the SIOC string for the cannon + other weapons.
-- pRemainSIOCParam = the SIOC parameter connected to the display of other wepaons (ex  ATGM, rockets) ammo count
-- pRNDSSIOCParam = the SIOC parameter connected to the display of the cannon ammo count

function AmmoCountersAndType(pRemainSIOCParam, pRNDSSIOCParam, pTypeSIOCParam)
    local lSIOC_SendString =""
    -- Get the device 
    local lWeaponSystem = GetDevice(12)
    --Check to see that the device is valid otherwise we return an emty string 
    if type(lWeaponSystem) ~= "table" then
        return ""
    end
    
    local lMainPanel = GetDevice(0)
    lMainPanel:update_arguments()
    
    local lGunSelected = lMainPanel:get_argument_value(615)
    local lTargetingSystemOn = lMainPanel:get_argument_value(433)  
   
    if lTargetingSystemOn == 1 then
      
      -- Somewhat ugly code due to most simmer not having the BS special gun/missile
        -- lockout system on their sticks.
        if lGunSelected == 0 then
            gLastGunStatus = "ARMED"    
        elseif lGunSelected == -1 then
            gLastGunStatus = "SAFE"
        end     
        --io.write(lGunSelected)
        --io.write("\n")
        --io.write(gLastGunStatus)
        --io.write("\n")
        --io.flush()
    
        -- Get and correctly round the ammo count. Ex Ammocount = 236 / 10 = 23.6. String match to "(%d+)" => 23
        local lCannonAmmoCount = string.match(lWeaponSystem:get_selected_gun_ammo_count() / 10, "(%d+)")
    
        -- Add the cannon ammo count to the SIOC string
        lSIOC_SendString = pRNDSSIOCParam.."="..lCannonAmmoCount..":"
    
        -- Get and calculate the ammo for rockets ATGM etc 
        local lArrayOfStationNumbers  = lWeaponSystem:get_selected_weapon_stations()	    
        local lSelectedStationsAmmoCount = 0
        for i=1,#lArrayOfStationNumbers do
            lSelectedStationsAmmoCount =
            lSelectedStationsAmmoCount + lWeaponSystem:get_weapon_count_on_station(lArrayOfStationNumbers[i])  
        end
    

        -- -999999 tells SIOC to turn of the display
        if (#lArrayOfStationNumbers ~= 0 and gLastGunStatus == "SAFE") then
            local lWeaponType   = lWeaponSystem:get_weapon_type_on_station(lArrayOfStationNumbers[1])
          
            --io.write(lWeaponType)
            --io.write("\n")
            
            lSIOC_SendString = lSIOC_SendString..pRemainSIOCParam.."="..lSelectedStationsAmmoCount..":"
        
            --io.write(weaponsTypeIndicator[lWeaponType] or "nil")
            --io.write("\n")
        
            -- Only update the weapons indicator display when the weapon actually changes
            -- Due to the fact that if you jettison the weapon on the station (lWeaponType = "EMPTY") 
            -- and then cycle the gun select the sim-display still displayes the weapontype eventhough the   
            -- weapon is in fact not there anymore. 
            local lWeaponIndicator
            if lWeaponType == "EMPTY" then 
                lWeaponIndicator = gLastWeaponType 
            else
                lWeaponIndicator = weaponsTypeIndicator[lWeaponType] or 0 
            end
          
            --io.write(lWeaponIndicator)
            --io.write("\n")
        
            if lWeaponIndicator > 0  then
                lSIOC_SendString = lSIOC_SendString..pTypeSIOCParam.."="..lWeaponIndicator..":"
                gLastWeaponType = lWeaponIndicator
            end
            
        else
            lSIOC_SendString = lSIOC_SendString..pRemainSIOCParam.."=-999999:"..pTypeSIOCParam.."=0"..":"
        end
    
    else
        lSIOC_SendString = lSIOC_SendString..pRemainSIOCParam.."=-999999:"..pTypeSIOCParam.."=0:"..pRNDSSIOCParam.."=-999999:"
    end
    --io.write(lSIOC_SendString)
    --io.write("\n")    
    --io.flush()  
    return lSIOC_SendString
end

-- Generate the SIOC string to reset (turn off) all indicator lamsp
function ResetIndicators(pIndicatorTables)
    local lIndicatorTable, lDevice_Arg ,lSIOC_Var 
    local lSIOC_SendString = ""
    
    for i , lIndicatorTable in pairs(pIndicatorTables) 
    do     
        for lSIOC_Var ,lDevice_Arg in pairs(lIndicatorTable) 
        do 
            lSIOC_SendString = lSIOC_SendString..lSIOC_Var.."=0:"
        end            
    end
    return lSIOC_SendString
end

function round(num, idp)
  local mult = 10^(idp or 0)
  return math.floor(num * mult + 0.5) / mult
end

-- Used togheter with a for loop to extract Sioc parameters and their value from a string
function SIOC_Parse(pSIOC_String)
    local i = -1
    return function ()
        i= string.find(pSIOC_String, ":",i+1)
        if i ~= nil then
            return tonumber(string.match(pSIOC_String, ":(%d+)=%d+",i)) , tonumber(string.match(pSIOC_String, ":%d+=(%d+)",i)) 
        end
    end
end


-- Simulation id
gSimID = os.time()

-- Connection status
gConnected = false
gLastAck = 0
gAckExpected = 0
gAckAttempts = 0

-- Blackshark Virtual Panel Host and Port
gBSVPHost = "127.0.0.1"
gBSVPPort = 8080


-- Network Functions
function SendConnectMessage()
    io.write("---Log: Connection Request Sent-----", "\n")
	c:send("*C"..gSimID.."\n")
	gAckExpected = 1
    gConnected = false
end

function ProcessBSVP()
	local t = LoGetModelTime()
	local name = LoGetPilotName()
	local altBar = LoGetAltitudeAboveSeaLevel()
	local altRad = LoGetAltitudeAboveGroundLevel()
	local pitch, bank, yaw = LoGetADIPitchBankYaw()
	local engine = LoGetEngineInfo()
	local HSI    = LoGetControlPanel_HSI()

	local vv     = 0.0
	local ball   = 0.0
	local speed  = 0.0
	local Gmeter = 0.0

	local rotorRPM = 0.0
	local barMeters = 0.0
	local barKilometers = 0.0
	local barPressure = 0.0
	local rotorPitch = 0.0
	
	local HSI_compass = 0.0
	local HSI_ZPU = 0.0
	local HSI_ZK = 0.0
	local HSI_KUR = 0.0

	local DistanceHundred = 0.0
	local DistanceTen = 0.0
	local DistanceUnit = 0.0

	local TempLH = 0.0
	local TempLT = 0.0
	local TempRH = 0.0
	local TempRT = 0.0
	local EngRPML = 0.0
	local EngRPMR = 0.0
	local Fuel1 = 0.0
	local Fuel2 = 0.0

	local VX = 0.0
	local VY = 0.0
	local VZ = 0.0

	local NoseGearUp    = 0.0
	local NoseGearDown  = 0.0
	local RightGearUp   = 0.0
	local RightGearDown = 0.0
	local LeftGearUp    = 0.0
	local LeftGearDown  = 0.0

	local IllPanels     = 0.0
	local IllAdi        = 0.0

	local MasterWarning = 0.0
	local NyMax         = 0.0

	local main_panel = GetDevice(0)

	   if main_panel then
	      main_panel:update_arguments() --             
	      --main_panel:get_argument_value(166) --    ,    mainpanel_init.lua
	      vv = main_panel:get_argument_value(24)
	      ball = main_panel:get_argument_value(108)
	      speed = main_panel:get_argument_value(51)
	      Gmeter = main_panel:get_argument_value(97)

   	      rotorRPM = main_panel:get_argument_value(52)
	      barMeters = main_panel:get_argument_value(573)
	      barKilometers = main_panel:get_argument_value(87)
	      barPressure = main_panel:get_argument_value(88)
	      rotorPitch = main_panel:get_argument_value(53)
		
	      HSI_compass = -main_panel:get_argument_value(112)

	      HSI_ZPU = main_panel:get_argument_value(118)
  	      HSI_ZK = main_panel:get_argument_value(124)

	      HSI_KUR = main_panel:get_argument_value(115)

	      DistanceHundred = main_panel:get_argument_value(117)
	      DistanceTen = main_panel:get_argument_value(527)
	      DistanceUnit = main_panel:get_argument_value(528)

	      TempLH = main_panel:get_argument_value(133)
   	      TempLT = main_panel:get_argument_value(566)
	      TempRH = main_panel:get_argument_value(134)
	      TempRT = main_panel:get_argument_value(567)
	      EngRPML = main_panel:get_argument_value(135)
	      EngRPMR = main_panel:get_argument_value(136)
	      Fuel1 = main_panel:get_argument_value(137)
	      Fuel2 = main_panel:get_argument_value(138)

	      VX = main_panel:get_argument_value(71)
	      VY = main_panel:get_argument_value(74)
	      VZ = main_panel:get_argument_value(266)


	      -----------------------------------------------------------------


	      NoseGearUp    = main_panel:get_argument_value(63)
              NoseGearDown  = main_panel:get_argument_value(64)
	      RightGearUp   = main_panel:get_argument_value(61)
	      RightGearDown = main_panel:get_argument_value(62)
	      LeftGearUp    = main_panel:get_argument_value(59)
	      LeftGearDown  = main_panel:get_argument_value(60)
 	      
              IllPanels     = main_panel:get_argument_value(803)*5
	      IllAdi        = main_panel:get_argument_value(798)*5

	      MasterWarning = main_panel:get_argument_value(44)*10
	      NyMax         = main_panel:get_argument_value(46)*10
	   end

	socket.try(bsvpc:send(string.format("t = %.2f, pitch = %.2f, bank = %.2f, yaw = %.2f, altBar = %.2f, altrad = %.2f, vv = %.2f, ball = %.2f, speed = %.2f, Gmeter = %.2f, rotorRPM = %.2f, barMeters = %.2f, barKilometers = %.2f, barPressure = %.2f, rotorPitch = %.2f, HSI_compass = %.2f, HSI_ZPU = %.2f, HSI_ZK = %.2f, HSI_KUR = %.2f, DistanceHundred = %.2f, DistanceTen = %.2f, DistanceUnit = %.2f, TempLH = %.2f, TempLT = %.2f, TempRH = %.2f, TempRT = %.2f, EngRPML = %.2f, EngRPMR = %.2f, Fuel1 = %.2f, Fuel2 = %.2f, VX = %.2f, VY = %.2f, VZ = %.2f, NoseGearUp = %.2f, NoseGearDown = %.2f, RightGearUp = %.2f, RightGearDown = %.2f, LeftGearUp = %.2f, LeftGearDown = %.2f, IllPanels = %.2f, IllAdi = %.2f, MasterWarning = %.2f, NyMax = %.2f\n", t, pitch, bank, yaw, altBar, altRad, vv, ball, speed, Gmeter, rotorRPM, barMeters, barKilometers, barPressure, rotorPitch, HSI_compass, HSI_ZPU, HSI_ZK, HSI_KUR, DistanceHundred, DistanceTen, DistanceUnit, TempLH, TempLT, TempRH, TempRT, EngRPML, EngRPMR, Fuel1, Fuel2, VX, VY, VZ, NoseGearUp, NoseGearDown, RightGearUp, RightGearDown, LeftGearUp, LeftGearDown, IllPanels, IllAdi, MasterWarning, NyMax)))
end



-- Device/switch specific functions
 

-- For a simple switch/pushbutton sends 0 (for pValue = 0) and  pOnValue (for pValue = 1)
-- to pDevice (ex 12 for WEAP-Interface). pNumber is the device_commands.Button_?? value from
-- clickabledata.lua, pOnValue is from the arg_lim = {{0.0, 1.0} part from clickabledata.lua. 
-- Set pInvert ~= nil to invert. 
function TwoPositionSwitch(pValue, pDevice, pNumber, pOnValue, pInvert)
    if pInvert then
        if pValue == 1 then
           pValue = 0
        else
           pValue = 1
        end
    end
 
    GetDevice(pDevice):performClickableAction(pNumber + 3000, pValue * pOnValue)
end


--For a rotary/rotary switch, sends (pValue - 1/10) to pDevice (ex 12 for WEAP-Interface)
-- Set your SIOC parameter to 1 for position 1, 2 for position 2.....etc.  
function SimpleRotary(pValue, pDevice, pNumber)
    GetDevice(pDevice):performClickableAction(pNumber + 3000,(pValue - 1)/10)
end

