-- Set the host IP and port for the SIOC server. 127.0.0.1 = localhost 
-- (if you run SIOC on the same PC as DCS:BS).
siocConfig = {hostIP = "192.168.1.13", hostPort = 8092}

-- Enter the SIOC parameter number for the Remain and RNDS disply on the Weapons Control panel
ammoCountersAndType = {Remain=200, RNDS=201, Type = 202}


-- Format [SIOC Parameter Value] = {Device ID, arg_number}
-- Device ID and arg_number can be found in Devices.lua and mainpanel_init.lua 
-- respectively.

dataLinkIndicators = {
[344] = {0,17},
[345] = {0,18},
[346] = {0,19},
[347] = {0,20},
[348] = {0,16},
[349] = {0,15},
[340] = {0,21},
[341] = {0,22},
[342] = {0,23},
[343] = {0,50},
[350] = {0,161},
[351] = {0,150},
[352] = {0,159}
}

weaponsInterfaceIndicators = {
[330] = {0,437},
[331] = {0,440},
[332] = {0,441},
[333] = {0,439},
[334] = {0,438}
}


FireExtinguishersPanel = {
[401] = {0,237},
[402] = {0,241},
[403] = {0,237},
[404] = {0,243},
[405] = {0,568}
}


LandingGearControlPanel = {
[387] = {0,63},
[388] = {0,64},
[389] = {0,61},
[390] = {0,62},
[391] = {0,59},
[392] = {0,60}
}


LaserWarningSystem = {
[378] = {0,25},
[379] = {0,28},
[380] = {0,26},
[381] = {0,27},
[382] = {0,31},
[383] = {0,32},
[385] = {0,33},
[386] = {0,34}
}


navigation = {
[335] = {0,330},
[336] = {0,331},
[337] = {0,332},
[338] = {0,333},
[339] = {0,334}
}


upperPanelLeftGroup = {
[353] = {0,170},
[354] = {0,175},
[355] = {0,172},
[356] = {0,166},
[357] = {0,176},
[358] = {0,165},
[359] = {0,171},
[360] = {0,179},
[361] = {0,188},
[362] = {0,205},
[363] = {0,207},
[364] = {0,208}
}


upperPanelRightGroup = {
[365] = {0,78},
[366] = {0,79},
[367] = {0,81},
[368] = {0,82},
[369] = {0,84},
[370] = {0,47},
[371] = {0,80},
[372] = {0,582},
[373] = {0,83},
[374] = {0,48},
[375] = {0,86},
[393] = {0,44},
[394] = {0,165},
[395] = {0,46},
[406] = {0,392},
[407] = {0,393},
[408] = {0,395},
[409] = {0,394},
[410] = {0,388},
[411] = {0,389},
[412] = {0,391},
[413] = {0,390}
}

PVI800 = {
[396] = {0,315},
[397] = {0,317},
[398] = {0,318},
[399] = {0,321}
}


-- Add the indicatortables to the main indicatortable
gIndicatorTables = {dataLinkIndicators, weaponsInterfaceIndicators, FireExtinguishersPanel, LandingGearControlPanel, LaserWarningSystem, navigation, upperPanelLeftGroup, upperPanelRightGroup, PVI800}


--gVariometerSIOCParam = 1111
--variometerServoCalTable = {{-10,1000},{10,100}}



-- General Format [SIOC Parameter Value] = {Function, input1, input2, input 3, input4}

-------------------------------------------------------------

-- Function TwoPositionSwitch

-- Format [SIOC Parameter Value] = {TwoPositionSwitch, Device ID, Button Nbr, OnValue, Inverse}
-- Device ID, Button Nbr and OnValue can be found in clickabledata.lua. Set Inverse to 1 
-- if you want to invert the switch, remove or set to nil if not.
-- 
-- Example Nbr 1 [508] = {TwoPositionSwitch, 12, 6, 1, 1} means that the switch is 
-- connected to SIOC parameter 1111, Device ID is 12 = devices.WEAP_INTERFACE, 
-- Button Nbr is 6 = Cannon round selector switch HE/AP, OnValue is 1 = we 
-- send 1 to the sim when the switch is on, Inverse is 1 so the switch is inverted.    

-- Example Nbr 2 [578] = {TwoPositionSwitch, 25, 5, 0.2} means that the switch is 
-- connected to SIOC parameter 578, Device ID is 25 = devices.DATALINK, 
-- Button Nbr is 5 = "DLNK to ALL", OnValue is 0.2 = we 
-- send 0.2 to the sim when the switch is on, Inverse is present so the switch 
-- is not inverted.

-- Note: The SIOC parameter value must be either 1 or 0, no other values are 
-- acceptable and will lead to unpredictable results.

-------------------------------------------------------------

-- Function SimpleRotary

-- Note: Do not use this function for an encoder rotary just for switch type 
-- rotaries like the Datalink ID selector etc)

-- Format [SIOC Parameter Value] = {SimpleRotary, Device ID, Button Nbr}
-- Device ID and Button Nbr can be found in clickabledata.lua.
-- The SIOC paramameter value for the rotary 
-- must start at 1 and increase by 1 for each clockwise position. 
-- I.e value should be 1 at 12 o'clock,  2 at 3 o'clock and 3 at 6 o'clock for
-- a 3 position rotary switch  

-- Example Nbr 1 [590] = {SimpleRotary, 25, 14} means that the rotary switch is 
-- connected to SIOC parameter 590, Device ID is 25 = devices.DATALINK, -- 
-- Button Nbr is 14 = Datalink self ID  

--------------------------------------------------------------

-- You can write your own funtions to parse other types of switches/input devices
-- etc. See ExportSupport.lua for examples. 


inputsTable = {

[501] = {TwoPositionSwitch, 12, 1, 1},
[502] = {TwoPositionSwitch, 12, 3, 1},
[503] = {TwoPositionSwitch, 12, 22, 1},
[504] = {TwoPositionSwitch, 12, 21, 1},
[505] = {TwoPositionSwitch, 12, 5, 1},
[508] = {TwoPositionSwitch, 12, 6, 1},
[509] = {TwoPositionSwitch, 12, 20, 1},
[510] = {SimpleRotary, 12, 4},
[513] = {TwoPositionSwitch, 11, 2, 1},
[514] = {TwoPositionSwitch, 11, 3, 1},
[515] = {TwoPositionSwitch, 45, 1, 1},
[517] = {TwoPositionSwitch, 45, 3, 1},
[518] = {TwoPositionSwitch, 52, 3, 1},
[519] = {TwoPositionSwitch, 52, 7, 1},
[520] = {TwoPositionSwitch, 52, 1, 1},
[521] = {TwoPositionSwitch, 52, 9, 1},
[522] = {TwoPositionSwitch, 40, 1, 1},
[523] = {TwoPositionSwitch, 40, 3, 1},
[524] = {TwoPositionSwitch, 4, 13, 1},
[525] = {TwoPositionSwitch, 4, 14, 1},
[526] = {TwoPositionSwitch, 3, 6, 1},
[527] = {TwoPositionSwitch, 3, 8, 1},
[528] = {TwoPositionSwitch, 34, 9, 1},
[529] = {TwoPositionSwitch, 34, 10, 1},
[530] = {TwoPositionSwitch, 7, 4, 1},
[531] = {TwoPositionSwitch, 60, 2, 1},
[532] = {TwoPositionSwitch, 23, 2, 1},
[533] = {TwoPositionSwitch, 12, 17, 1},
[534] = {TwoPositionSwitch, 11, 1, 1},
[535] = {TwoPositionSwitch, 12, 16, 1},
[539] = {SimpleRotary, 25, 15},
[540] = {TwoPositionSwitch, 12, 10, 1},
[541] = {TwoPositionSwitch, 12, 12, 1},
[542] = {TwoPositionSwitch, 12, 11, 1},
[543] = {TwoPositionSwitch, 12, 13, 1},
[545] = {TwoPositionSwitch, 14, 1, 0.2},
[546] = {TwoPositionSwitch, 14, 3, 0.2},
[555] = {SimpleRotary, 12, 14},
[560] = {TwoPositionSwitch, 36, 1, 1},
[561] = {TwoPositionSwitch, 33, 1, 1},
[562] = {TwoPositionSwitch, 33, 2, 1},
[563] = {TwoPositionSwitch, 33, 3, 1},
[564] = {TwoPositionSwitch, 33, 4, 1},
[565] = {TwoPositionSwitch, 33, 5, 1},
[566] = {SimpleRotary, 33, 6},
[567] = {SimpleRotary, 28, 3},
[578] = {TwoPositionSwitch, 25, 5, 0.2},
[579] = {TwoPositionSwitch, 25, 1, 0.2},
[580] = {TwoPositionSwitch, 25, 2, 0.2},
[581] = {TwoPositionSwitch, 25, 3, 0.2},
[582] = {TwoPositionSwitch, 25, 4, 0.2},
[583] = {TwoPositionSwitch, 25, 6, 0.2},
[584] = {TwoPositionSwitch, 25, 7, 0.2},
[585] = {TwoPositionSwitch, 25, 8, 0.2},
[586] = {TwoPositionSwitch, 25, 9, 0.2},
[587] = {TwoPositionSwitch, 25, 10, 0.2},
[588] = {TwoPositionSwitch, 25, 11, 0.2},
[589] = {TwoPositionSwitch, 25, 12, 0.2},
[590] = {TwoPositionSwitch, 25, 13, 0.2},
[591] = {SimpleRotary, 22, 1},
[592] = {TwoPositionSwitch, 22, 3, 1},
[593] = {TwoPositionSwitch, 22, 4, 1},
[594] = {TwoPositionSwitch, 22, 5, 1},
[595] = {TwoPositionSwitch, 22, 6, 1},
[596] = {TwoPositionSwitch, 22, 7, 1},
[597] = {TwoPositionSwitch, 22, 8, 1},
[598] = {TwoPositionSwitch, 22, 9, 1},
[599] = {TwoPositionSwitch, 34, 1, 1, 1},
[600] = {TwoPositionSwitch, 34, 4, 1},
[601] = {TwoPositionSwitch, 34, 5, 1},
[602] = {TwoPositionSwitch, 20, 1, 0.2},
[603] = {TwoPositionSwitch, 20, 2, 0.2},
[604] = {TwoPositionSwitch, 20, 3, 0.2},
[605] = {TwoPositionSwitch, 20, 4, 0.2},
[606] = {TwoPositionSwitch, 20, 5, 0.2},
[607] = {TwoPositionSwitch, 20, 6, 0.2},
[608] = {TwoPositionSwitch, 20, 7, 0.2},
[609] = {TwoPositionSwitch, 20, 8, 0.2},
[610] = {TwoPositionSwitch, 20, 9, 0.2},
[611] = {TwoPositionSwitch, 20, 10, 0.2},
[612] = {TwoPositionSwitch, 20, 11, 0.2},
[613] = {TwoPositionSwitch, 20, 15, 0.2},
[614] = {TwoPositionSwitch, 20, 17, 0.2},
[615] = {TwoPositionSwitch, 20, 18, 0.2},
[616] = {TwoPositionSwitch, 20, 19, 0.2},
[617] = {TwoPositionSwitch, 20, 23, 0.2},
[618] = {TwoPositionSwitch, 9, 1, 1},
[619] = {TwoPositionSwitch, 9, 2, 1},
[620] = {TwoPositionSwitch, 9, 3, 1},
[621] = {TwoPositionSwitch, 9, 4, 1},
[622] = {TwoPositionSwitch, 9, 5, 1},
[623] = {TwoPositionSwitch, 9, 6, 0.4},
[624] = {TwoPositionSwitch, 9, 6, -0.4},
[625] = {TwoPositionSwitch, 9, 7, 1},
[626] = {TwoPositionSwitch, 44, 1, 1},
[627] = {TwoPositionSwitch, 44, 2, 1},
}